summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/config/appearance/appearanceconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/config/appearance/appearanceconfig.cpp')
-rw-r--r--kopete/kopete/config/appearance/appearanceconfig.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kopete/kopete/config/appearance/appearanceconfig.cpp b/kopete/kopete/config/appearance/appearanceconfig.cpp
index aff81a39..106622c9 100644
--- a/kopete/kopete/config/appearance/appearanceconfig.cpp
+++ b/kopete/kopete/config/appearance/appearanceconfig.cpp
@@ -179,16 +179,16 @@ public:
}
};
// TODO: Someday, this configuration dialog must(not should) use KConfigXT
AppearanceConfig::AppearanceConfig(TQWidget *parent, const char* /*name*/, const TQStringList &args )
-: KCModule( KopeteAppearanceConfigFactory::instance(), parent, args )
+: TDECModule( KopeteAppearanceConfigFactory::instance(), parent, args )
{
d = new Private;
(new TQVBoxLayout(this))->setAutoAdd(true);
d->mAppearanceTabCtl = new TQTabWidget(this, "mAppearanceTabCtl");
- KConfig *config = TDEGlobal::config();
+ TDEConfig *config = TDEGlobal::config();
config->setGroup( "ChatWindowSettings" );
// "Emoticons" TAB ==========================================================
@@ -629,7 +629,7 @@ void AppearanceConfig::slotInstallChatStyle()
if( !styleToInstall.isEmpty() )
{
TQString stylePath;
- if( KIO::NetAccess::download( styleToInstall, stylePath, this ) )
+ if( TDEIO::NetAccess::download( styleToInstall, stylePath, this ) )
{
int styleInstallReturn = 0;
styleInstallReturn = ChatWindowStyleManager::self()->installStyle( stylePath );
@@ -662,7 +662,7 @@ void AppearanceConfig::slotInstallChatStyle()
}
// removeTempFile check if the file is a temp file, so it's ok for local files.
- KIO::NetAccess::removeTempFile( stylePath );
+ TDEIO::NetAccess::removeTempFile( stylePath );
}
}
}
@@ -846,14 +846,14 @@ void AppearanceConfig::removeSelectedEmoticonTheme()
return;
KURL themeUrl(TDEGlobal::dirs()->findResource("emoticons", themeName+"/"));
- KIO::NetAccess::del(themeUrl, this);
+ TDEIO::NetAccess::del(themeUrl, this);
updateEmoticonlist();
}
void AppearanceConfig::slotGetEmoticonThemes()
{
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup( "KNewStuff" );
config->writeEntry( "ProvidersUrl",
"http://download.kde.org/khotnewstuff/emoticons-providers.xml" );
@@ -179,16 +179,16 @@ public:
}
};
-// TODO: Someday, this configuration dialog must(not should) use KConfigXT
+// TODO: Someday, this configuration dialog must(not should) use TDEConfigXT
AppearanceConfig::AppearanceConfig(TQWidget *parent, const char* /*name*/, const TQStringList &args )